@@ -1,5 +1,4 @@
-// Moving Lambolt Terms to/from runtime, and building dynamic functions.
-
+/// Moves HVM Terms from runtime, and building dynamic functions.
 use crate::language as lang;
 use crate::rulebook as rb;
 use crate::runtime as rt;
@@ -81,10 +80,6 @@ pub fn as_code(mem: &Worker, comp: &Option<rb::RuleBook>, host: u64) -> String {
     // count: &'a mut u32,
   }
 
-  // TODO: more efficient, immutable data structure
-  // Note: Because of clone? Use a bit-string:
-  // struct BitString { O{...}, I{...}, E }
-  #[derive(Clone)]
   struct Stacks {
     stacks: HashMap<Lnk, Vec<bool>>,
   }
@@ -113,7 +108,7 @@ pub fn as_code(mem: &Worker, comp: &Option<rb::RuleBook>, host: u64) -> String {
     // Should investigate if it is needed or not.
 
     //if ctx.seen.contains(&term) {
-    //"@".to_string()
+    //  "@".to_string()
     //} else {
     match rt::get_tag(term) {
       rt::LAM => {
@@ -246,7 +241,11 @@ pub fn as_code(mem: &Worker, comp: &Option<rb::RuleBook>, host: u64) -> String {
   go(ctx, &mut stacks, term, 0)
 }
 
-pub fn as_term(mem: &Worker, comp: &Option<rb::RuleBook>, host: u64) -> Result<Box<lang::Term>, String> {
+pub fn as_term(
+  mem: &Worker,
+  comp: &Option<rb::RuleBook>,
+  host: u64,
+) -> Result<Box<lang::Term>, String> {
   //println!("readback: {}", as_code(mem, comp, host));
   lang::read_term(&as_code(mem, comp, host))
 }
